package com.atguigu.spzx.manger.controller;

import com.atguigu.log.annotation.Log;
import com.atguigu.spzx.manger.service.SysMenuService;
import com.atguigu.spzx.model.entity.system.SysMenu;
import com.atguigu.spzx.model.vo.result.Result;
import com.atguigu.spzx.model.vo.result.ResultCodeEnum;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "菜单管理接口")
@RestController
@RequestMapping(value = "/admin/system/sysMenu")
public class SysMenuController {

    @Autowired
    private SysMenuService sysMenuService;

    @Log(title = "查询菜单", businessType = 0)
    @Operation(summary = "查询菜单", description = "查询菜单内容")
    @GetMapping("/findNodes")
    public Result<List<SysMenu>> findNodes() {
        List<SysMenu> list = sysMenuService.findNodes();
        return Result.build(list, ResultCodeEnum.SUCCESS);
    }

    @Log(title = "添加菜单", businessType = 1)
    @Operation(summary = "添加菜单", description = "添加菜单")
    @PostMapping("save")
    public Result<SysMenu> save(@RequestBody SysMenu sysMenu) {
        sysMenuService.save(sysMenu);
        return Result.success();
    }

    @Log(title = "修改菜单", businessType = 2)
    @Operation(summary = "修改菜单", description = "修改菜单")
    @PutMapping("update")
    public Result<SysMenu> update(@RequestBody SysMenu sysMenu) {
        sysMenuService.update(sysMenu);
        return Result.success();
    }

    @Log(title = "删除菜单", businessType = 3)
    @Operation(summary = "删除菜单", description = "删除菜单")
    @DeleteMapping("removeById/{id}")
    public Result<Long> removeById(@PathVariable Long id) {
        sysMenuService.removeById(id);
        return Result.success();
    }
}